@@ -668,7 +668,7 @@ class ImageSurface(Surface):
         Typical usage will be of the form::
 
             from cairocffi import ImageSurface
-            stride = ImageSurface.stride_for_width(format, width)
+            stride = ImageSurface.format_stride_for_width(format, width)
             data = bytearray(stride * height)
             surface = ImageSurface(format, width, height, data, stride)
 
@@ -720,7 +720,7 @@ class ImageSurface(Surface):
         """
         return ffi.buffer(
             cairo.cairo_image_surface_get_data(self._pointer),
-            size=self.get_stride() * self.get_height())
+            self.get_stride() * self.get_height())
 
     def get_format(self):
         """Return the :ref:`FORMAT` string of the surface."""
@@ -1274,9 +1274,39 @@ class RecordingSurface(Surface):
         return tuple(extents)
 
 
+class Win32PrintingSurface(Surface):
+    """ Creates a cairo surface that targets the given DC.
+
+    The DC will be queried for its initial clip extents,
+    and this will be used as the size of the cairo surface.
+    The DC should be a printing DC; antialiasing will be ignored,
+    and GDI will be used as much as possible to draw to the surface.
+
+    The returned surface will be wrapped using the paginated surface
+    to provide correct complex rendering behaviour;
+    cairo_surface_show_page() and associated methods must be used
+    for correct output.
+
+    :param hdc:
+        The DC to create a surface for,
+        as obtained from :func:`win32gui.CreateDC`.
+        **Note**: this unsafely inteprets an integer as a pointer.
+        Make sure it actually points to a valid DC!
+    :type hdc: int
+
+    *New in cairocffi 0.6*
+
+    """
+    def __init__(self, hdc):
+        pointer = cairo.cairo_win32_printing_surface_create(
+            ffi.cast('void*', hdc))
+        Surface.__init__(self, pointer)
+
+
 SURFACE_TYPE_TO_CLASS = {
     constants.SURFACE_TYPE_IMAGE: ImageSurface,
     constants.SURFACE_TYPE_PDF: PDFSurface,
     constants.SURFACE_TYPE_SVG: SVGSurface,
     constants.SURFACE_TYPE_RECORDING: RecordingSurface,
+    constants.SURFACE_TYPE_WIN32_PRINTING: Win32PrintingSurface
 }
